@@ -16,8 +16,8 @@ define('DRUPAL_ROOT', getcwd());
 define('MAINTENANCE_MODE', 'install');
 
 // Exit early if running an incompatible PHP version to avoid fatal errors.
-if (version_compare(PHP_VERSION, '5.2.4') < 0) {
-  print 'Your PHP installation is too old. Drupal requires at least PHP 5.2.4. See the <a href="http://drupal.org/requirements">system requirements</a> page for more information.';
+if (version_compare(PHP_VERSION, '5.3.3') < 0) {
+  print 'Your PHP installation is too old. Drupal requires at least PHP 5.3.3. See the <a href="https://www.drupal.org/docs/7/system-requirements">system requirements</a> page for more information.';
   exit;
 }
 
